@@ -66,6 +66,9 @@ namespace HostExt {
  * class, and are certainly not required to use this actual class.
  * But we do strongly recommend it.
  *
+ * This class is not thread-safe; use it from a single application
+ * thread, or guard access to it with a mutex.
+ *
  * \note This class was introduced in version 1.1 of the Vamp plugin SDK.
  */
 
@@ -124,6 +127,34 @@ public:
      */
     PluginKeyList listPlugins();
 
+    /**
+     * Search for available Vamp plugins in libraries with the given
+     * library names, and return a list of them in the order in which
+     * they were found. Do not attempt to load any plugin libraries
+     * other than those named.
+     *
+     * The library names should be supplied without path or
+     * suffix. For example, use "vamp-example-plugins" to find plugins
+     * in /install/path/of/vamp-example-plugins.dll (or .so etc). This
+     * is the same concept of "library name" as appears in the plugin
+     * key: \see composePluginKey().
+     */
+    PluginKeyList listPluginsIn(std::vector<std::string> libraryNames);
+
+    /**
+     * Search for available Vamp plugins in libraries other than those
+     * with the given library names, and return a list of them in the
+     * order in which they were found. Do not attempt to load any of
+     * the libraries named.
+     *
+     * The library names should be supplied without path or
+     * suffix. For example, use "vamp-example-plugins" to find plugins
+     * not appearing in /install/path/of/vamp-example-plugins.dll (or
+     * .so etc). This is the same concept of "library name" as appears
+     * in the plugin key: \see composePluginKey().
+     */
+    PluginKeyList listPluginsNotIn(std::vector<std::string> libraryNames);
+
     /**
      * AdapterFlags contains a set of values that may be OR'd together
      * to indicate in which circumstances PluginLoader should use a
@@ -197,11 +228,17 @@ public:
     Plugin *loadPlugin(PluginKey key,
                        float inputSampleRate,
                        int adapterFlags = 0);
-
+    
     /**
      * Given a Vamp plugin library name and plugin identifier, return
      * the corresponding plugin key in a form suitable for passing in to
      * loadPlugin().
+     *
+     * (Note that the reverse of this is not well-defined and is not
+     * offered in this API - consider using getLibraryPathForPlugin
+     * instead. See documentation for the PluginKey type for details.)
+     *
+     * \see PluginKey, getLibraryPathForPlugin, loadPlugin
      */
     PluginKey composePluginKey(std::string libraryName,
                                std::string identifier);
